==> rivendell-2.12.0.zip: rivendell-2.12.0/ripcd/btadms4422.h <==
// btadms4422.h
//
// A Rivendell switcher driver for the BroadcastTools ADMS 44.22
//
//   (C) Copyright 2002-2016 Fred Gleason <fredg@paravelsystems.com>
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License version 2 as
//   published by the Free Software Foundation.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public
//   License along with this program; if not, write to the Free Software
//   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

#ifndef BTADMS4422_H
#define BTADMS4422_H

#include <rd.h>
#include <rdmatrix.h>
#include <rdmacro.h>
#include <rdtty.h>
#include <rdoneshot.h>

#include <switcher.h>

#define BTADMS4422_UNIT_ID 0
#define BTADMS4422_POLL_INTERVAL 100
#define BTADMS4422_GPI_PINS 16


class BtAdms4422 : public Switcher
{
 Q_OBJECT
 public:
  BtAdms4422(RDMatrix *matrix,QObject *parent=0,const char *name=0);
  ~BtAdms4422();
  RDMatrix::Type type();
  unsigned gpiQuantity();
  unsigned gpoQuantity();
  bool primaryTtyActive();
  bool secondaryTtyActive();
  void processCommand(RDMacro *cmd);

 private slots:
  void processStatus();
  void gpiOneshotData(int value);
  void gpoOneshotData(int value);

 private:
  RDTTYDevice *bt_device;
  RDOneShot *bt_gpi_oneshot;
  RDOneShot *bt_gpo_oneshot;
  int bt_matrix;
  int bt_inputs;
  int bt_outputs;
  int bt_gpis;
  int bt_gpos;
  int bt_istate;
  bool bt_gpi_state[BTADMS4422_GPI_PINS];
  bool bt_gpi_mask[BTADMS4422_GPI_PINS];
};


#endif  // BTADMS4422_H

==> rivendell-2.14.0.zip: rivendell-2.14.0/ripcd/btadms4422.h <==
// btadms4422.h
//
// A Rivendell switcher driver for the BroadcastTools ADMS 44.22
//
//   (C) Copyright 2002-2016 Fred Gleason <fredg@paravelsystems.com>
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License version 2 as
//   published by the Free Software Foundation.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public
//   License along with this program; if not, write to the Free Software
//   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

#ifndef BTADMS4422_H
#define BTADMS4422_H

#include <rd.h>
#include <rdmatrix.h>
#include <rdmacro.h>
#include <rdtty.h>
#include <rdoneshot.h>

#include <switcher.h>

#define BTADMS4422_UNIT_ID 0
#define BTADMS4422_POLL_INTERVAL 100
#define BTADMS4422_GPI_PINS 16

class BtAdms4422 : public Switcher
{
 Q_OBJECT
 public:
  BtAdms4422(RDMatrix *matrix,QObject *parent=0);
  ~BtAdms4422();
  RDMatrix::Type type();
  unsigned gpiQuantity();
  unsigned gpoQuantity();
  bool primaryTtyActive();
  bool secondaryTtyActive();
  void processCommand(RDMacro *cmd);

 private slots:
  void processStatus();
  void gpiOneshotData(int value);
  void gpoOneshotData(int value);

 private:
  RDTTYDevice *bt_device;
  RDOneShot *bt_gpi_oneshot;
  RDOneShot *bt_gpo_oneshot;
  int bt_matrix;
  int bt_inputs;
  int bt_outputs;
  int bt_gpis;
  int bt_gpos;
  int bt_istate;
  bool bt_gpi_state[BTADMS4422_GPI_PINS];
  bool bt_gpi_mask[BTADMS4422_GPI_PINS];
};


#endif  // BTADMS4422_H
